pilas.depurador.ModoPosicion

Package pilas :: Module depurador :: Class ModoPosicion |
[hide private]
[frames] | no frames]

# Class ModoPosicion

source code

       object --+
                |
    ModoDepurador --+
                    |
                   ModoPosicion

Instance Methods | [hide private]
__init__(self, depurador) x.__init__(...) initializes x; see help(type(x)) for signature | source code
dibuja_al_actor(self, motor, painter, lienzo, actor) | source code
sale_del_modo(self) | source code
Inherited from `ModoDepurador`: `comienza_dibujado`, `orden_de_tecla`, `termina_dibujado` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| tecla = ``'``F12``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, depurador) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### dibuja_al_actor(self, motor, painter, lienzo, actor) | source code
Overrides: ModoDepurador.dibuja_al_actor

### sale_del_modo(self) | source code
Overrides: ModoDepurador.sale_del_modo